/*
Ce programme cf.c (crée fichiers), écrit en langage C sous Ubuntu, 
effectue les tâches suivantes :
1 - saisie par l'utilisateur de deux nombres entiers p et q;
2 - création automatique, dans le répertoire du programme, de 
    q-p+1 répertoires nommés p, p+1, ...q
3- recopie dans chacun des q-p+1 répertoires le fichier page.html 
    (se trouvant dans le répertoire du programme) en lui donnant le 
    même nom que le répertoire avec l'extension .html.
    Par exemple, page.html est copiée avec le nom "1.html" dans le 
    répertoire "1", "2.html" dans le répertoire "2", "3".html dans le répertoire "3" etc...
compilation:  gcc cf.c -o cf 
exécution: ./cf
*/
#include <stdio.h>
#include <stdlib.h>
#include <sys/stat.h>
#include <string.h>

// Fonction pour copier un fichier
void copyFile(const char *source, const char *destination) {
    FILE *src, *dst;
    char ch;

    src = fopen(source, "r");
    if (src == NULL) {
        perror("Erreur lors de l'ouverture du fichier source");
        exit(1);
    }

    dst = fopen(destination, "w");
    if (dst == NULL) {
        fclose(src);
        perror("Erreur lors de l'ouverture du fichier destination");
        exit(1);
    }

    while ((ch = fgetc(src)) != EOF) {
        fputc(ch, dst);
    }

    fclose(src);
    fclose(dst);
}

int main() {
    int p, q;

    // Saisie des nombres entiers p et q
    printf("Entrez la valeur de p : ");
    scanf("%d", &p);

    printf("Entrez la valeur de q : ");
    scanf("%d", &q);

    // Vérification que p est inférieur ou égal à q
    if (p > q) {
        printf("Erreur : p doit être inférieur ou égal à q.\n");
        return 1;
    }

    // Création des répertoires
    for (int i = p; i <= q; i++) {
        char directory_name[20];  // Nom du répertoire (assumption: moins de 20 caractères)
        char file_name[50];       // Nom du fichier (augmenté pour plus de sécurité)
        
        sprintf(directory_name, "%d", i);
        snprintf(file_name, sizeof(file_name), "%s/%d.html", directory_name, i);

        // Création du répertoire
        if (mkdir(directory_name, 0777) == -1) {
            perror("Erreur lors de la création du répertoire");
            return 1;
        }

        // Copie du fichier page.html dans le répertoire avec le nom correspondant
        copyFile("page.html", file_name);

        printf("Répertoire %s créé avec succès. Fichier %s copié.\n", directory_name, file_name);
    }

    return 0;
}
